%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Program name: Hybrid Color Mapping (HCM)
%
% Reference: Please cite this paper if one uses this HCM package. % J. Zhou, C. Kwan, and B. Budavari, Hyperspectral 
% Image Super-Resolution: A Hybrid Color Mapping Approach, SPIE 
% Journal of Applied Remote Sensing, Vol. 10, 035024, September, 
% 2016. http://dx.doi.org/10.1117/1.JRS.10.035024
%
% Purpose: It is used to fuse one high spatial resolution (HR)
% multispectral (MS) image cube with a low spatial resolution 
% (LR)hyperspectral (HS) image cube to generate a HR HS image 
% cube.
%
% Usage: Users need to supply input images and parameters; the lr 
% bands are used to increase the number of bands in HR MS image 
% cube. Sometimes, we see better performance. See reference paper 
% for details. The patch size is a design parameter, which allows 
% us to perform HCM locally. The regularization parameter is to 
% deal with singular conditions.
%
% Inputs: HR MS image cube; LR HS image cube (need to resize to 
% the same image size as the HR MS image); parameters (lr 
% bands, patch size and regularization parameter)
%
% Outputs: HR HS image cube
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function nX = HCM(HR_image,LR_image,lrbands,patchSize,reg_param)

% Add extra bands; it is better to add bands beyond the RGB bands
HR_image(:,:,size(HR_image,3)+1) = ones(size(HR_image,1), size(HR_image,2));
HR_image(:,:,size(HR_image,3)+(1:length(lrbands))) = LR_image(:,:,lrbands);

% Perform local color mapping
nX = cml(LR_image,HR_image,patchSize,reg_param);

end